@@ -66,7 +66,7 @@ void set_volume()
 
 void setup_menu()
 {
-    SDL_Surface *back, *logo;
+    SDL_Surface *back;
     Font        *font_y, *font_w, *small_font;
     Menu        *_main, *gfx, *audio;
     MEnt        *entry;
@@ -84,13 +84,12 @@ void setup_menu()
         _("Until Key Pressed")
     };
 
-    // load and assign gfx //
+    // load and assign gfx (back now includes logo) //
     back = load_surf("title.bmp", SDL_HWSURFACE);
     SDL_SetColorKey( back, 0, 0 );
-    logo = load_surf("logo.bmp", SDL_HWSURFACE);
     font_y = load_fixed_font("f_yellow.bmp", 32, 96, 10);
     font_w = load_fixed_font("f_white.bmp", 32, 96, 10);
-    MM_Ini(back->w / 2, back->h - 100, 50, back, logo, font_y, font_w);
+    MM_Ini(back->w / 2, back->h - 100, 50, back, NULL, font_y, font_w);
 
     /* add copyright and homepage */
     small_font = load_fixed_font( "stan_font.bmp" , 32, 96, 8);
